@@ -16,8 +16,8 @@
 # First argument ($1) expects 'multibackend' as value for setting appropriate
 # tempest conf opts, all other values will assume singlebackend installation.
 
-sudo chown -R jenkins:stack $BASE/new/tempest
-sudo chown -R jenkins:stack $BASE/data/tempest
+sudo chown -R $USER:stack $BASE/new/tempest
+sudo chown -R $USER:stack $BASE/data/tempest
 sudo chmod -R o+rx $BASE/new/devstack/files
 
 # Import devstack functions 'iniset', 'iniget' and 'trueorfalse'
@@ -54,6 +54,18 @@ else
 fi
 iniset $TEMPEST_CONFIG share backend_names $BACKENDS_NAMES
 
+
+# Grab the supported API micro-versions from the code
+_API_VERSION_REQUEST_PATH=$BASE/new/manila/manila/api/openstack/api_version_request.py
+_DEFAULT_MIN_VERSION=$(awk '$0 ~ /_MIN_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
+_DEFAULT_MAX_VERSION=$(awk '$0 ~ /_MAX_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
+# Override the *_api_microversion tempest options if present
+MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
+MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
+# Set these options in tempest.conf
+iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
+iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
+
 # Set two retries for CI jobs
 iniset $TEMPEST_CONFIG share share_creation_retry_number 2
 
@@ -78,6 +90,7 @@ RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=${RUN_MANILA_HOST_ASSISTED_MIGRATION_TE
 RUN_MANILA_DRIVER_ASSISTED_MIGRATION_TESTS=${RUN_MANILA_DRIVER_ASSISTED_MIGRATION_TESTS:-False}
 RUN_MANILA_MOUNT_SNAPSHOT_TESTS=${RUN_MANILA_MOUNT_SNAPSHOT_TESTS:-False}
 RUN_MANILA_MIGRATION_WITH_PRESERVE_SNAPSHOTS_TESTS=${RUN_MANILA_MIGRATION_WITH_PRESERVE_SNAPSHOTS_TESTS:-False}
+RUN_MANILA_IPV6_TESTS=${RUN_MANILA_IPV6_TESTS:-False}
 
 MANILA_CONF=${MANILA_CONF:-/etc/manila/manila.conf}
 
@@ -178,6 +191,7 @@ if [[ "$DRIVER" == "lvm" ]]; then
     RUN_MANILA_SHRINK_TESTS=False
     RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS=True
     RUN_MANILA_MOUNT_SNAPSHOT_TESTS=True
+    RUN_MANILA_IPV6_TESTS=True
     iniset $TEMPEST_CONFIG share enable_ip_rules_for_protocols 'nfs'
     iniset $TEMPEST_CONFIG share enable_user_rules_for_protocols 'cifs'
     iniset $TEMPEST_CONFIG share image_with_share_tools 'manila-service-image-master'
@@ -316,21 +330,48 @@ export OS_USER_DOMAIN_NAME=$ADMIN_DOMAIN_NAME
 source $BASE/new/manila/contrib/ci/common.sh
 manila_wait_for_drivers_init $MANILA_CONF
 
-# (aovchinnikov): extra rules are needed to allow instances talk to host.
-sudo iptables -N manila-nfs
-sudo iptables -I INPUT 1 -j manila-nfs
+
 TCP_PORTS=(2049 111 32803 892 875 662)
 UDP_PORTS=(111 32769 892 875 662)
-for port in ${TCP_PORTS[*]}; do
-    sudo iptables -A manila-nfs -m tcp -p tcp --dport $port -j ACCEPT
-done
-for port in ${UDP_PORTS[*]}; do
-    sudo iptables -A manila-nfs -m udp -p udp --dport $port -j ACCEPT
+for ipcmd in iptables ip6tables; do
+    # (aovchinnikov): extra rules are needed to allow instances talk to host.
+    sudo $ipcmd -N manila-nfs
+    sudo $ipcmd -I INPUT 1 -j manila-nfs
+    for port in ${TCP_PORTS[*]}; do
+        sudo $ipcmd -A manila-nfs -m tcp -p tcp --dport $port -j ACCEPT
+    done
+    for port in ${UDP_PORTS[*]}; do
+        sudo $ipcmd -A manila-nfs -m udp -p udp --dport $port -j ACCEPT
+    done
 done
 
+source $BASE/new/devstack/openrc admin admin
+public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
+iniset $TEMPEST_CONFIG network public_network_id $public_net_id
+
+# Now that all plugins are loaded, setup BGP here
+if [ $(trueorfalse False MANILA_SETUP_IPV6) == True ]; then
+    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
+    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
+    neutron bgp-peer-create --peer-ip ::1 --remote-as 200 bgppeer
+    neutron bgp-speaker-peer-add bgpspeaker bgppeer
+fi
+
+# Set config to run IPv6 tests according to env var
+iniset $TEMPEST_CONFIG share run_ipv6_tests $RUN_MANILA_IPV6_TESTS
+
+if ! [[ -z "$OVERRIDE_IP_FOR_NFS_ACCESS" ]]; then
+    # Set config to use specified IP as access rule on NFS scenario tests
+    # in order to workaround multiple NATs between the VMs and the storage
+    # controller
+    iniset $TEMPEST_CONFIG share override_ip_for_nfs_access $OVERRIDE_IP_FOR_NFS_ACCESS
+fi
+
 echo "Running tempest manila test suites"
-sudo -H -u jenkins tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
+cd $BASE/new/tempest/
+sudo -H -u $USER tempest run -r $MANILA_TESTS --concurrency=$MANILA_TEMPEST_CONCURRENCY
 RETVAL=$?
+cd -
 
 
 # If using the dummy driver, configure the second run. We can't use the
@@ -351,8 +392,10 @@ if [[ "$DRIVER" == "dummy" ]]; then
     manila type-key default set driver_handles_share_servers=False
 
     echo "Running tempest manila test suites for DHSS=False mode"
-    sudo -H -u jenkins tox -eall-plugin $MANILA_TESTS -- --concurrency=$MANILA_TEMPEST_CONCURRENCY
+    cd $BASE/new/tempest/
+    sudo -H -u $USER tempest run -r  $MANILA_TESTS --concurrency=$MANILA_TEMPEST_CONCURRENCY
     RETVAL2=$?
+    cd -
     save_tempest_results 2
 
     # Exit with last code if first succeeded else exit with first error code
