@@ -843,6 +843,15 @@ function stop_manila {
     done
 }
 
+function install_manila_tempest_plugin {
+    MANILA_TEMPEST_PLUGIN_REPO=${MANILA_TEMPEST_PLUGIN_REPO:-${GIT_BASE}/openstack/manila-tempest-plugin.git}
+    MANILA_TEMPEST_PLUGIN_BRANCH=${MANILA_TEMPEST_PLUGIN_BRANCH:-master}
+    MANILA_TEMPEST_PLUGIN_DIR=$DEST/manila-tempest-plugin
+
+    git_clone $MANILA_TEMPEST_PLUGIN_REPO $MANILA_TEMPEST_PLUGIN_DIR $MANILA_TEMPEST_PLUGIN_BRANCH
+    setup_develop $MANILA_TEMPEST_PLUGIN_DIR
+}
+
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
@@ -1147,6 +1156,8 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     fi
     ###########################################################################
 
+    echo_summary "Fetching and installing manila-tempest-plugin system-wide"
+    install_manila_tempest_plugin
     echo_summary "Update Tempest config"
     update_tempest
 fi
